@@ -159,6 +159,7 @@ Pixmap nxagentScreenSaverPixmap;
 
 XlibGC nxagentBitmapGC;
 
+#ifdef NX_CONFINE_WINDOW
 /*
  * The "confine" window is used in the nxagentConstrainCursor
  * procedure. We are currently overriding the original Xnest
@@ -166,6 +167,7 @@ XlibGC nxagentBitmapGC;
  */
 
 Window nxagentConfineWindow;
+#endif
 
 Pixmap nxagentIconPixmap;
 Pixmap nxagentIconShape;
@@ -1105,6 +1107,42 @@ void nxagentResetSignalHandlers(void)
   nxagentInitTimer();
 }
 
+/*
+ * currently unused it seems
+ */
+void nxagentOpenConfineWindow(void)
+{
+#ifdef NX_CONFINE_WINDOW
+  nxagentConfineWindow = XCreateWindow(nxagentDisplay,
+                                       DefaultRootWindow(nxagentDisplay),
+                                       0, 0, 1, 1, 0, 0,
+                                       InputOnly,
+                                       CopyFromParent,
+                                       0L, NULL);
+
+  if (nxagentReportWindowIds) {
+    fprintf(stderr, "NXAGENT_WINDOW_ID: CONFINEMENT_WINDOW,WID:[0x%x]\n",
+              nxagentConfineWindow);
+  }
+
+  #ifdef DEBUG
+  {
+    char *winname = NULL;
+    if (-1 != asprintf(&winname, "%s Confine", nxagentWindowName))
+    {
+      Xutf8SetWMProperties(nxagentDisplay, nxagentConfineWindow,
+                               winname, winname, NULL , 0 , NULL, NULL, NULL);
+      SAFE_free(winname);
+    }
+  }
+  #endif
+
+  #ifdef TEST
+  fprintf(stderr, "%s: Created agent's confine window with id [0x%x].\n", __func__, nxagentConfineWindow);
+  #endif
+#endif
+}
+
 void nxagentOpenDisplay(int argc, char *argv[])
 {
   if (!nxagentDoFullGeneration)
@@ -1298,21 +1336,7 @@ FIXME: Use of nxagentParentWindow is strongly deprecated.  We need
   fprintf(stderr, "nxagentOpenDisplay: Going to create agent's confine window.\n");
   #endif
 
-  nxagentConfineWindow = XCreateWindow(nxagentDisplay,
-                                       DefaultRootWindow(nxagentDisplay),
-                                       0, 0, 1, 1, 0, 0,
-                                       InputOnly,
-                                       CopyFromParent,
-                                       0L, NULL);
-
-  if (nxagentReportWindowIds) {
-    fprintf(stderr, "NXAGENT_WINDOW_ID: CONFINEMENT_WINDOW,WID:[0x%x]\n",
-              nxagentConfineWindow);
-  }
-  #ifdef TEST
-  fprintf(stderr, "nxagentOpenDisplay: Created agent's confine window with id [0x%x].\n",
-              nxagentConfineWindow);
-  #endif
+  nxagentOpenConfineWindow();
 
   if (!(nxagentUserGeometry.flag & XValue))
   {
@@ -2665,21 +2689,7 @@ Bool nxagentReconnectDisplay(void *p0)
   fprintf(stderr, "nxagentReconnectDisplay: Going to create agent's confine window.\n");
   #endif
 
-  nxagentConfineWindow = XCreateWindow(nxagentDisplay,
-                                       DefaultRootWindow(nxagentDisplay),
-                                       0, 0, 1, 1, 0, 0,
-                                       InputOnly,
-                                       CopyFromParent,
-                                       0L, NULL);
-
-  if (nxagentReportWindowIds) {
-    fprintf(stderr, "NXAGENT_WINDOW_ID: CONFINEMENT_WINDOW,WID:[0x%x]\n",
-              nxagentConfineWindow);
-  }
-  #ifdef TEST
-  fprintf(stderr, "nxagentReconnectDisplay: Created agent's confine window with id [0x%x].\n",
-              nxagentConfineWindow);
-  #endif
+  nxagentOpenConfineWindow();
 
   useXpmIcon = nxagentMakeIcon(nxagentDisplay, &nxagentIconPixmap, &nxagentIconShape);
 
