@@ -110,9 +110,9 @@ Window nxagentCreateIconWindow(void);
 Bool nxagentMagicPixelZone(int x, int y);
 
 Bool nxagentResizeScreen(ScreenPtr pScreen, int width, int height,
-                             int mmWidth, int mmHeight);
+                             int mmWidth, int mmHeight, Bool doresize);
 
-int nxagentChangeScreenConfig(int screen, int width, int height);
+int nxagentChangeScreenConfig(int screen, int width, int height, Bool doresize);
 
 int nxagentAdjustRandRXinerama(ScreenPtr pScreen);
 
